
/*
 * Simple parallel port output control program for Linux
 * Written and copyright by Tomi Engdahl 1998-2005
 * (e-mail: tomi.engdahl@hut.fi)
 *
 * The program output the data value to PC parallel port data pins
 * (default lpt1 I/O address 0x378). The data values are given as the
 * command line parameter to the program. The number can be
 * in decimal (0..255) or hexadecimal format (0x00..0xFF).
 *
 *
 * Supported port identifiers
 *  LPT1DATA
 *   
 *
 * Supported commands
 *
 *  READVALUE       Read data, gives output as decimal number
 *  READBITS bits   Reads the specified bits in the specified order (0..7)
 * 
 *  WRITE value     Writes specified value to port
 *  AND value       Reads port, performs AND with given value, writes value back
 *  OR value        Reads port, performs OR with given value, writes value back
 *  SETBITS bits    Sets given bits to 1 
 *  RESETBITS bits  Sets given bits to 0
 *  TOGGLEBITS bits Toggles specified bit values  
 *
 * value can be gives as decimal number or heaxadecimal starting with 0x
 * bits is a list of bit position identifiers from 0 to 7
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/io.h>

#define base 0x378           /* printer port base address */


/*
 * String compare routine, gives 1 when strings match, 0 otherwise
 */
int stringMatch(char * str1, char * str2)
{
  if (strcmp(str1,str2) == 0)
  {
    return 1; 
  }
  return 0;
}


/* 
 * Routine to convert port 
 */
int PortIDtoAddress(char * portID)
{
}


int ReadPort(char * portID)
{
}

int WritePort(char * portID, int value)
{
}



int main(int argc, char **argv)
{                    
  int value;

  if (argc!=2)
    fprintf(stderr, "Error: Wrong number of arguments. This program needs one argument which is number between 0 and 255.\n"), exit(1);
  if (sscanf(argv[1],"%i",&value)!=1)
    fprintf(stderr, "Error: Parameter is not a number.\n"), exit(1);
  if ((value<0) || (value>255))
    fprintf(stderr, "Error: Invalid numeric value. The parameter number must be between 0 and 255\n"), exit(1);
  if (ioperm(base,1,1))
    fprintf(stderr, "Error: Couldn't get the port at %x\n", base), exit(1);

  outb((unsigned char)value, base);
}                                            



